A simulator of 2-D positive charges interacting with each other and 
a bounding electric field. Can consider either quasi-electrostatic approximation 
or quasi-electromagnetostatics approximation (through the Darwin Hamiltonian).
Built on PyTorch mostly.

Mostly a toy project done from boredom.


## Installing
On this folder:
```sh
pip install .
```

## Usage
To open the GUI
```sh
import fieldbillard
fieldbillard.run()
```

![Alt text](docs/figs/examplegui.png?raw=true "GUI")